@@ -1,14 +1,11 @@
-import re
-from enum import Enum
+try:
+    from normatrix.source.config import REG_TYPELINE
+    from normatrix.source.config import TypeLine
+except ModuleNotFoundError:
+    from normatrix.normatrix.source.config import REG_TYPELINE
+    from normatrix.normatrix.source.config import TypeLine
 
-class TypeLine(Enum):
-    FUNCTION = 1
-    MACRO = 2
-    STRUCT = 3
-    ENUM = 4
-    GLOBAL = 5
-    COMMENT = 6
-    NONE = 7
+import re
 
 class CFileParse:
     def __init__(self, filepath, name):
@@ -41,28 +38,11 @@ class CFileParse:
         self.sub_filelines = lines.split('\n')
 
 def get_status(lines: str) -> (TypeLine, str):
-    reg = [
-        '^( ){0,}?\/\*(.*?\n{0,}){0,}\*\/',
-        '^( ){0,}?\/\/.*',
-        '((\w{1,}(\*{0,}) ){1,}(\*){0,}\w{1,})\(((void)|((\w{1,} {0,}){1,}(\*){0,} (\*){0,}\w{1,}(\[\d{0,}\]){0,}(, {0,}(\n {0,}){0,1}){0,}){1,4})\)\n\{((.*)\n){1,}?\}',
-        '^ {0,}#\w{1,}.*',
-        '^(typedef ){0,1}(struct )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};',
-        '^(typedef ){0,1}(enum )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};',
-        '^(static ){0,1}(const ){0,1}\w{1,} \*{0,}\w{1,}(\[[0-9]{0,}\]){0,1} = ((\w{0,})|({\n{0,1} {0,}\w{0,}(,\n{0,1} {0,}\w{0,}){0,})|)\n{0,1}}{0,1};'
-    ]
-    status = [
-        TypeLine.COMMENT,
-        TypeLine.COMMENT,
-        TypeLine.FUNCTION,
-        TypeLine.MACRO,
-        TypeLine.STRUCT,
-        TypeLine.ENUM,
-        TypeLine.GLOBAL
-    ]
-    for i, regex in enumerate(reg):
-        res = re.search(regex, lines, re.MULTILINE)
-        if res != None and res.start() <= len(lines.split('\n')[0]):
-            return (status[i], lines[res.start():res.end()])
+    for type_reg, regex_list in REG_TYPELINE.items():
+        for regex in regex_list:
+            res = regex.match(lines)
+            if res != None and res.start() <= len(lines.split('\n')[0]):
+                return (type_reg, lines[res.start():res.end()])
     return (TypeLine.NONE, lines.split('\n')[0])
 
 def parse(filepath: str, dirname: str) -> CFileParse:
